You are viewing a plain text version of this content. The canonical link for it is here.
Posted to java-dev@axis.apache.org by gd...@apache.org on 2004/12/09 15:54:37 UTC

svn commit: r111388 - in webservices/axis/trunk/java/dev/scratch/prototype2/src: java/org/apache/axis/client java/org/apache/axis/engine java/org/apache/axis/impl/transport java/org/apache/axis/impl/transport/http test/org/apache/axis/engine

Author: gdaniels
Date: Thu Dec  9 06:54:35 2004
New Revision: 111388

URL: http://svn.apache.org/viewcvs?view=rev&rev=111388
Log:
Spelling/cleanup
Modified:
   webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/client/Call.java
   webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/engine/AxisEngine.java
   webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/engine/Phase.java
   webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/engine/ReceiverLocator.java
   webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/impl/transport/AbstractTransportReceiver.java
   webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/impl/transport/http/SimpleHTTPReceiver.java
   webservices/axis/trunk/java/dev/scratch/prototype2/src/test/org/apache/axis/engine/EngineTest.java

Modified: webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/client/Call.java
Url: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/client/Call.java?view=diff&rev=111388&p1=webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/client/Call.java&r1=111387&p2=webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/client/Call.java&r2=111388
==============================================================================
--- webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/client/Call.java	(original)
+++ webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/client/Call.java	Thu Dec  9 06:54:35 2004
@@ -86,7 +86,7 @@
             
             MessageContext reposne = createIncomingMessageContext(urlConnect.getInputStream(),engine);
             reposne.setServerSide(false);
-            engine.recive(reposne);
+            engine.receive(reposne);
             SOAPEnvelope envelope = reposne.getEnvelope();
             
             SOAPBody body = envelope.getBody();
@@ -149,7 +149,7 @@
                         log.info("Starting new Thread "); 
                         MessageContext reposne = createIncomingMessageContext(urlConnect.getInputStream(),engine);
                         reposne.setServerSide(false);
-                        engine.recive(reposne);
+                        engine.receive(reposne);
                         SOAPEnvelope envelope = reposne.getEnvelope();
                         
                         SOAPBody body = envelope.getBody();

Modified: webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/engine/AxisEngine.java
Url: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/engine/AxisEngine.java?view=diff&rev=111388&p1=webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/engine/AxisEngine.java&r1=111387&p2=webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/engine/AxisEngine.java&r2=111388
==============================================================================
--- webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/engine/Phase.java	(original)
+++ webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/engine/Phase.java	Thu Dec  9 06:54:35 2004
@@ -87,7 +87,7 @@
         return phaseName;
     }
     /**
-     * @param name The name to set.
+     * @param phaseName The name to set.
      */
     public void setName(String phaseName) {
         this.phaseName = phaseName;

Modified: webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/engine/ReceiverLocator.java
Url: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/engine/ReceiverLocator.java?view=diff&rev=111388&p1=webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/engine/ReceiverLocator.java&r1=111387&p2=webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/engine/ReceiverLocator.java&r2=111388
==============================================================================
--- webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/engine/ReceiverLocator.java	(original)
+++ webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/engine/ReceiverLocator.java	Thu Dec  9 06:54:35 2004
@@ -23,11 +23,11 @@
  * @author Srinath Perera(hemapani@opensource.lk)
  */
 public class ReceiverLocator {
-    public static Receiver locateReciver(MessageContext msgCtx)throws AxisFault{
+    public static Receiver locateReceiver(MessageContext msgCtx)throws AxisFault{
         
         //File wsdlFile = msgCtx.getService().getParameter("wsdlFile");
         //parse the WSDL find the patterns 
-        //create a reciver
+        //create a receiver
         return new InOutSyncReceiver();
     }
 }

Modified: webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/impl/transport/AbstractTransportReceiver.java
Url: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/impl/transport/AbstractTransportReceiver.java?view=diff&rev=111388&p1=webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/impl/transport/AbstractTransportReceiver.java&r1=111387&p2=webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/impl/transport/AbstractTransportReceiver.java&r2=111388
==============================================================================
--- webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/impl/transport/AbstractTransportReceiver.java	(original)
+++ webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/impl/transport/AbstractTransportReceiver.java	Thu Dec  9 06:54:35 2004
@@ -91,7 +91,7 @@
                     if (socket != null) {
                         MessageContext msgContext = parseTheTransport(engine,socket.getInputStream());
                         storeOutputInfo(msgContext,socket.getOutputStream());
-                        engine.recive(msgContext);
+                        engine.receive(msgContext);
                         this.socket.close();
                         this.socket = null;
                     }

Modified: webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/impl/transport/http/SimpleHTTPReceiver.java
Url: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/impl/transport/http/SimpleHTTPReceiver.java?view=diff&rev=111388&p1=webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/impl/transport/http/SimpleHTTPReceiver.java&r1=111387&p2=webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/impl/transport/http/SimpleHTTPReceiver.java&r2=111388
==============================================================================
--- webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/impl/transport/http/SimpleHTTPReceiver.java	(original)
+++ webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/impl/transport/http/SimpleHTTPReceiver.java	Thu Dec  9 06:54:35 2004
@@ -165,7 +165,6 @@
      * @param httpRequest StringBuffer for GET / POST
      * @param cookie first cookie header (if doSessions)
      * @param cookie2 second cookie header (if doSessions)
-     * @param headers HTTP headers to transfer to MIME headers
      * @return Content-Length
      */
     protected int parseHeaders(NonBlockingBufferedInputStream is,
@@ -472,7 +471,7 @@
 
 
     /* (non-Javadoc)
-     * @see org.apache.axis.impl.transport.AbstractTransportReciver#storeOutputInfo(org.apache.axis.context.MessageContext, java.io.OutputStream)
+     * @see org.apache.axis.impl.transport.AbstractTransportReceiver#storeOutputInfo(org.apache.axis.context.MessageContext, java.io.OutputStream)
      */
     protected void storeOutputInfo(
         MessageContext msgContext,

Modified: webservices/axis/trunk/java/dev/scratch/prototype2/src/test/org/apache/axis/engine/EngineTest.java
Url: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/dev/scratch/prototype2/src/test/org/apache/axis/engine/EngineTest.java?view=diff&rev=111388&p1=webservices/axis/trunk/java/dev/scratch/prototype2/src/test/org/apache/axis/engine/EngineTest.java&r1=111387&p2=webservices/axis/trunk/java/dev/scratch/prototype2/src/test/org/apache/axis/engine/EngineTest.java&r2=111388
==============================================================================
--- webservices/axis/trunk/java/dev/scratch/prototype2/src/test/org/apache/axis/engine/EngineTest.java	(original)
+++ webservices/axis/trunk/java/dev/scratch/prototype2/src/test/org/apache/axis/engine/EngineTest.java	Thu Dec  9 06:54:35 2004
@@ -61,9 +61,9 @@
         AxisEngine engine = new AxisEngine(engineRegistry);
         engine.send(mc);
     }
-    public void testRecive()throws Exception{
+    public void testReceive()throws Exception{
         AxisEngine engine = new AxisEngine(engineRegistry);
-        engine.recive(mc);
+        engine.receive(mc);
     }
     protected void tearDown() throws Exception {
     }
--- webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/engine/AxisEngine.java	(original)
+++ webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/engine/AxisEngine.java	Thu Dec  9 06:54:35 2004
@@ -28,7 +28,7 @@
 import org.apache.commons.logging.LogFactory;
 
 /**
  *  There is one engine for the Server and the Client. the send() and recive() 
  *  Methods are the basic operations the Sync, Async messageing are build on top.
  *  Two methods will find and execute the <code>CommonExecuter</code>'s Transport,
  *  Global,Service.  
@@ -59,7 +59,7 @@
         log.info("end the send()");
     }
     
-    public void recive(MessageContext mc)throws AxisFault{
+    public void receive(MessageContext mc)throws AxisFault{
         Service service = null;
         try{
             if(mc.isServerSide()){
@@ -74,13 +74,13 @@
             if(mc.isServerSide()){
                 OpNameFinder finder = new OpNameFinder();
                 finder.invoke(mc);
-                Receiver reciver = ReceiverLocator.locateReciver(mc);
-                reciver.invoke(mc);
+                Receiver receiver = ReceiverLocator.locateReceiver(mc);
+                receiver.invoke(mc);
             }
         }catch(AxisFault e){
             handleFault(mc,e,service);
         }
-        log.info("end the recive()");
+        log.info("end the receive()");
     }    
     
     private void sendTheMessage(MessageContext msgCtx)throws AxisFault{
@@ -93,7 +93,7 @@
             //TODO log and exit
             log.error("Error in fault flow",e);
         }else{
-            log.debug("recive failed",e);
+            log.debug("receive failed",e);
             mc.setProcessingFault(true);
             if(service != null){
                 ExecutionChain faultExeChain = service.getFaultExecutionChain();
@@ -28,7 +28,7 @@
 
 /**
- *  There is one engine for the Server and the Client. the send() and recive() 
+ *  There is one engine for the Server and the Client. the send() and receive()
  *  Methods are the basic operations the Sync, Async messageing are build on top.
  *  Two methods will find and execute the <code>CommonExecuter</code>'s Transport,

Modified: webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/engine/Phase.java
Url: http://svn.apache.org/viewcvs/webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/engine/Phase.java?view=diff&rev=111388&p1=webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/engine/Phase.java&r1=111387&p2=webservices/axis/trunk/java/dev/scratch/prototype2/src/java/org/apache/axis/engine/Phase.java&r2=111388
==============================================================================